@@ -83,7 +83,7 @@ AVAILABILITY_ZONES = [
     'af-south-1a', 'af-south-1b', 'af-south-1c',
     'ap-east-1a', 'ap-east-1b', 'ap-east-1c',
     'ap-northeast-1a', 'ap-northeast-1b', 'ap-northeast-1c', 'ap-northeast-1d',
-    'ap-northeast-2a', 'ap-northeast-2b', 'ap-northeast-2c',
+    'ap-northeast-2a', 'ap-northeast-2b', 'ap-northeast-2c', 'ap-northeast-2d',
     'ap-northeast-3a',
     'ap-south-1a', 'ap-south-1b', 'ap-south-1c',
     'ap-southeast-1a', 'ap-southeast-1b', 'ap-southeast-1c',
@@ -104,7 +104,7 @@ AVAILABILITY_ZONES = [
     'us-gov-east-1a', 'us-gov-east-1b', 'us-gov-east-1c',
     'us-gov-west-1a', 'us-gov-west-1b', 'us-gov-west-1c',
     'us-west-1a', 'us-west-1b', 'us-west-1c',
-    'us-west-2a', 'us-west-2b', 'us-west-2c', 'us-west-2d', 'us-west-2-lax-1a',
+    'us-west-2a', 'us-west-2b', 'us-west-2c', 'us-west-2d', 'us-west-2-lax-1a', 'us-west-2-lax-1b',
 ]
 
 FUNCTIONS = [
@@ -136,26 +136,26 @@ PSEUDOPARAMS = [
 
 LIMITS = {
     'Mappings': {
-        'number': 100,
-        'attributes': 64,
+        'number': 200,
+        'attributes': 200,
         'name': 255  # in characters
     },
     'Outputs': {
-        'number': 60,
+        'number': 200,
         'name': 255,  # in characters
         'description': 1024  # in bytes
     },
     'Parameters': {
-        'number': 60,
+        'number': 200,
         'name': 255,  # in characters
         'value': 4096  # in bytes
     },
     'Resources': {
-        'number': 200,
+        'number': 500,
         'name': 255  # in characters
     },
     'template': {
-        'body': 460800,  # in bytes
+        'body': 1000000,  # in bytes
         'description': 1024  # in bytes
     },
     'threshold': 0.9,  # for rules about approaching the other limit values
